pub enum KeywordHardness {
Hard,
Soft,
}Expand description
The hardness of a keyword.
Variants
Hard
Hard keywords present when an identifier is expected will fail to parse.
Soft
Soft keywords are not fully reserved identifiers, they instead only have a different meaning when directly expected. Soft keywords can be used as identifiers.